################################################################
# LES SIMULATIONS DU CHANGEMENT CLIMATIQUE EN ILE DE FRANCE
# Utilisation des données de DRIAS Les futurs du climat
# Nouveau format NCDF (de + en + utilisé en climatologie) : fr.wikipedia.org/wiki/NetCDF
################################################################

setwd("~//Documents/ElementR_Raster/Simulations/")

library(ncdf)
library(raster)
library(rasterVis)
library(RColorBrewer)

# Ici fichiers bruts venant de DRIAS : par ex. tasmax_metro_IPSL_WRF_rcp4.5_QT_RCP4.5_20060101-21001231.nc
# tasmax correspond à T° maximale à proximité du sol / tasmin la T° minimale
# IPSL WRF : simulations faites par l'IPSL (Institut Pierre Simon Laplace), utilisant le modèle LMDz puis WRF
# rcp4.5 : scénario du GIEC RCP Representative Concentration Pathway, qui simule ici un forçage énergétique de +4.5 W/m2
# 20060101-21001231 : projections du 1/1/2006 au 31/12/2100

Tx_brut <- open.ncdf("tasmax_metro_IPSL_WRF_rcp4.5_QT_RCP4.5_20060101-21001231.nc")
Tn_brut <- open.ncdf("tasmin_metro_IPSL_WRF_rcp4.5_QT_RCP4.5_20060101-21001231.nc")
print.ncdf(Tx_brut)
Tx <- get.var.ncdf(Tx_brut,"tasmax")
Tn <- get.var.ncdf(Tn_brut,"tasmin")
dim(Tn)

# Comme les fichiers bruts de DRIAS ont "perdu" la dimension géographique
# on la ré-introduit, en ajoutant ici les coordonnées des points du modèle (en Lambert93)
lambertX <- c(620000,628000,636000,644000,612000,
              580000,588000,596000,604000,652000,
              660000,668000,676000,564000,572000,
              556000,684000,548000,540000)
lambertY <- c(2353000,2361000,2369000,2377000,2385000,
              2393000,2401000,2409000,2417000,2425000,
              2433000,2441000,2449000,2457000,2465000)

# on crée également un vecteur Temps pour faciliter la manipulation
time <- seq(as.Date("20060101",format="%Y%m%d"), as.Date("21001231",format="%Y%m%d"), by="day")

# Transformation des K en °C
Tx <- Tx - 273.15
Tn <- Tn - 273.15

# Est-ce que la distribution statistique des T° est la même entre les 30 premières années et les 30 dernières 
# Pour les Tn
First30 <- seq(which(time == "2006-01-01"), which(time == "2035-12-31"))
Last30 <- seq(which(time == "2071-01-01"), which(time == "2100-12-31"))

Per1 <- histogram(Tn[10,7,First30] , col=F, border="blue" )
Per2 <- histogram(Tn[10,7,Last30], col=F, border="red")
Per1 + Per2

# Pour les Tx
Per1 <- histogram(Tx[10,7,First30] , col=F, border="blue" )
Per2 <- histogram(Tx[10,7,Last30], col=F, border="red")
Per1 + Per2

# Pour créer des RasterBrick (format raster) des Tn et des Tx
Tn_b <- brick(Tn)
Tx_b <- brick(Tx)

pal <- rev(brewer.pal(11,"RdBu"))    
breaks <- seq(6,11, by=0.5)

moyTn_Per1 <- mean(Tn_b[[First30]], na.rm = T)
moyTn_Per2 <- mean(Tn_b[[Last30]], na.rm = T)
spplot(moyTn_Per1, at=breaks, col.regions=pal)
spplot(moyTn_Per2, at=breaks, col.regions=pal)

# Quelle est l'évolution des T° en été ?
# [...]

